@@ -14,6 +14,12 @@ if TYPE_CHECKING:
         Audio,
         Poke,
         MarketFace,
+        GreyTips,
+        Video,
+        Service,
+        File,
+        Markdown,
+        Keyboard,
     )
 
 # T = TypeVar(
@@ -42,4 +48,10 @@ Element: TypeAlias = Union[
     "Audio",
     "Poke",
     "MarketFace",
+    "GreyTips",
+    "Video",
+    "Service",
+    "File",
+    "Markdown",
+    "Keyboard",
 ]
