@@ -1,4 +1,5 @@
-from typing import Any, Callable, Coroutine, Dict, TYPE_CHECKING
+from typing import Any, Callable, TYPE_CHECKING
+from collections.abc import Coroutine
 
 from lagrange.client.wtlogin.sso import SSOPacket
 
@@ -11,7 +12,7 @@ if TYPE_CHECKING:
 class PushDeliver:
     def __init__(self, client: "Client"):
         self._client = client
-        self._handle_map: Dict[
+        self._handle_map: dict[
             str, Callable[["Client", SSOPacket], Coroutine[None, None, Any]]
         ] = {}
 
@@ -20,6 +21,6 @@ class PushDeliver:
 
     async def execute(self, cmd: str, sso: SSOPacket):
         if cmd not in self._handle_map:
-            logger.warning(f"Unsupported command: {cmd}")
+            logger.warning(f"Unsupported command: {cmd}({len(sso.data)})")
         else:
             return await self._handle_map[cmd](self._client, sso)
